@@ -26,9 +26,9 @@
 #include <QMenu>
 #include <QPushButton>
 #include <QSortFilterProxyModel>
-#include <KAction>
+#include <QAction>
 #include <KFilterProxySearchLine>
-#include <KLocale>
+#include <KLocalizedString>
 
 Palapeli::CollectionView::CollectionView(QWidget* parent)
 	: QWidget(parent)
@@ -37,15 +37,30 @@ Palapeli::CollectionView::CollectionView(QWidget* parent)
 	, m_proxyModel(new QSortFilterProxyModel(this))
 {
 	//setup view
-	connect(m_view, SIGNAL(activated(QModelIndex)), this, SLOT(handleActivated(QModelIndex)));
-	m_view->setAlternatingRowColors(true);
+	connect(m_view, &QListView::activated, this, &CollectionView::handleActivated);
+
+	// Set up for multi-column display of the Puzzle Collection, which
+	// allows the user to see more of the collection at one time.
+	m_view->setWrapping(true);
+	m_view->setResizeMode(QListView::Adjust);
+	m_view->setUniformItemSizes(true);
+	m_view->setFlow(QListView::LeftToRight);
+
+	// Avoid a resize loop (with the scrollbar appearing and disappearing)
+	// when the number of items and display-columns hits a bad combination.
+	m_view->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+
 	m_view->setMouseTracking(true);
 	m_view->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	m_view->setVerticalScrollMode(QListView::ScrollPerPixel); // Smooth.
 	//setup proxy model
 	m_view->setModel(m_proxyModel);
 	connect(m_view->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), SLOT(handleSelectionChanged()));
 	m_proxyModel->setDynamicSortFilter(true);
-	m_proxyModel->sort(Qt::DisplayRole, Qt::AscendingOrder);
+	m_proxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
+	m_proxyModel->setSortLocaleAware(true);
+	m_proxyModel->setSortRole(Qt::DisplayRole);
+	m_proxyModel->sort(0, Qt::AscendingOrder);
 	//TODO: save sorting role between sessions
 	//setup filter search line
 	KFilterProxySearchLine* searchLine = new KFilterProxySearchLine(this);
@@ -60,13 +75,16 @@ Palapeli::CollectionView::CollectionView(QWidget* parent)
 	m_sortByPieceCount->setCheckable(true);
 	m_sortByTitle->setChecked(true);
 	m_sortByPieceCount->setChecked(false);
-	connect(sortMenu, SIGNAL(triggered(QAction*)), SLOT(sortMenuTriggered(QAction*)));
+	connect(sortMenu, &QMenu::triggered, this, &CollectionView::sortMenuTriggered);
 	//construct layout
 	QGridLayout* layout = new QGridLayout(this);
 	layout->addWidget(sortButton, 0, 0);
 	layout->addWidget(searchLine, 0, 1);
 	layout->addWidget(m_view, 1, 0, 1, 2);
-	layout->setMargin(0);
+	// Removed this because setMargin is obsolete and (0) cuts off the right
+	// hand and bottom edges of the search and ListView widgets --- on Apple
+	// OSX at least. The default margin is 11 pixels all round and looks OK.
+	// layout->setContentsMargins(0, 0, 0, 0);
 }
 
 void Palapeli::CollectionView::setModel(QAbstractItemModel* model)
@@ -111,9 +129,9 @@ void Palapeli::CollectionView::sortMenuTriggered(QAction* action)
 	if (action == m_sortByPieceCount)
 		sortRole = Palapeli::Collection::PieceCountRole;
 	//update sorting and menu
-	m_proxyModel->sort(sortRole, Qt::AscendingOrder);
+	m_proxyModel->setSortRole(sortRole);
 	m_sortByTitle->setChecked(sortRole == Qt::DisplayRole);
 	m_sortByPieceCount->setChecked(sortRole == Palapeli::Collection::PieceCountRole);
 }
 
-#include "collection-view.moc"
+
